/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Leopold, T., Skopek, J., and F. Schulz (2018). 
  Gender Convergence in Housework Time: A Life Course and Cohort Perspective
  Sociological Science. 		
  
  01_pool_samples.do 
  
  Pool SOEP samples. Select sample. Generate some variables. 
 ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

do config
set more off

use "${tempDir}/00_prepare", clear

////
// Sample A (West German 1984+)
////
preserve

// keep only sample A (West Germans)
keep if psample == 1

// restrict to those born in Germany 
keep if germborn == 1

// restrict to those who clearly reported to live in West Germany in 1989
// or, if that information is missing, are in Western sample region
gen west = loc1989 == 2 if loc1989 < .
replace west = sampreg == 1 if west >= . & sampreg < .
keep if west == 1

unique pid // 16487 individuals

* Different measurement in 1984
drop if syear == 1984

// drop cases in age younger than 20 in 1985
drop if gebjahr > 1965

// drop cases in age older than 65 in 1985
drop if gebjahr < 1920


unique pid // 7638 individuals, 120076 obs

xtset pid syear
xtdes, pat(20)
tempfile A
save `A'
restore 


////
// Sample E (Pile up 1998)
////
preserve 
// keep only sample E (E 1998 Aufstockung)
keep if psample == 5

// restrict to those born in Germany 
keep if germborn == 1

// restrict to those who clearly reported to live in West Germany in 1989
// or, if that information is missing, are in Western sample region
gen west = loc1989 == 2 if loc1989 < .
replace west = sampreg == 1 if west >= . & sampreg < .
keep if west == 1

unique pid // 2049 individuals


// drop cases in age younger than 20 in 1998
drop if gebjahr > 1978

// drop cases in age older than 65 in 1998
drop if gebjahr < 1933


unique pid // 1088 individuals, 10375 obs

xtset pid syear
xtdes, pat(20)
tempfile E
save `E'

restore 


////
// Sample F (Pile up 2000)
////
preserve 
// keep only sample F (F 2000 Aufstockung)
keep if psample == 6

// restrict to those born in Germany 
keep if germborn == 1

// restrict to those who clearly reported to live in West Germany in 1989
// or, if that information is missing, are in Western sample region
gen west = loc1989 == 2 if loc1989 < .
replace west = sampreg == 1 if west >= . & sampreg < .
keep if west == 1

unique pid //  11369 individuals

// drop cases in age younger than 20 in 2000
drop if gebjahr > 1980

// drop cases in age older than 65 in 2000
drop if gebjahr < 1935


unique pid //  5673 individuals, 52680 obs

xtset pid syear
xtdes, pat(20)
tempfile F
save `F'
restore 


////
// Sample H (Pile up 2006)
////
preserve 
// keep only sample H (H 2006 Aufstockung)
keep if psample == 8

// restrict to those born in Germany 
keep if germborn == 1

// restrict to those who clearly reported to live in West Germany in 1989
// or, if that information is missing, are in Western sample region
gen west = loc1989 == 2 if loc1989 < .
replace west = sampreg == 1 if west >= . & sampreg < .
keep if west == 1

unique pid //  2488 individuals

// drop cases in age younger than 20 in 2006
drop if gebjahr > 1986

// drop cases in age older than 65 in 2006
drop if gebjahr < 1941


unique pid //  1217 individuals, 7803 obs

xtset pid syear
xtdes, pat(20)
tempfile H
save `H'
restore 


////
// Sample J (Pile up 2011)
////
preserve 
// keep only sample J (J 2011 Aufstockung)
keep if psample == 10

// restrict to those born in Germany 
keep if germborn == 1

// restrict to those who clearly reported to live in West Germany in 1989
// or, if that information is missing, are in Western sample region
gen west = loc1989 == 2 if loc1989 < .
replace west = sampreg == 1 if west >= . & sampreg < .
keep if west == 1

unique pid //  4549 individuals


// drop cases in age younger than 21 in 2011 (to have a round cohort boundary 1920 - 1990)
drop if gebjahr > 1990

// drop cases in age older than 65 in 2011
drop if gebjahr < 1946


unique pid // 2105 individuals, 7578 obs

xtset pid syear
xtdes, pat(20)
tempfile J
save `J'
restore 


////
// Sample K (Pile up 2012)
////
preserve 
// keep only sample K (K 2012 Aufstockung)
keep if psample == 11

// restrict to those born in Germany 
keep if germborn == 1

// restrict to those who clearly reported to live in West Germany in 1989
// or, if that information is missing, are in Western sample region
gen west = loc1989 == 2 if loc1989 < .
replace west = sampreg == 1 if west >= . & sampreg < .
keep if west == 1

unique pid //  2256 individuals

// drop cases in age younger than 22 in 2012 (to have a round cohort boundary 1920 - 1990)
drop if gebjahr > 1990

// drop cases in age older than 65 in 2012
drop if gebjahr < 1947



unique pid // 1050 individuals, 3027 obs

xtset pid syear
xtdes, pat(20)
tempfile K
save `K'
restore 

// Merge samples 
use `A', clear	// 1985 (actually 1984, but the first wave is skipped): 1985 --> 2014 (up to 30 obs)
append using `E' // 1998 --> 2014 (up to 17 obs)	
append using `F' // 2000 --> 2014 (up to 15 obs)	
append using `H' // 2006 --> 2014 (up to 9 obs)	
append using `J' // 2011 --> 2014 (up to 4 obs)
append using `K' // 2012 --> 2014 (up to 3 obs)

// XT 
xtset pid syear

// 1985->2014
xtdes if psample==1

// 2012->2014
xtdes if psample==11

// Some variables
sum gebjahr age syear
// cohort variable centered at mid-cohort divided by 10 (10 year units)
gen cgebj = (gebj - 1955)/10
gen cgebj2 = cgebj^2
gen cgebj3 = cgebj^3

// age variable centered at some mid-age (e.g. 45) divided by 10 (10 year units)
gen cage = (age - 45)/10
gen cage2 = cage^2
gen cage3 = cage^3
gen cage4 = cage^4
gen cage5 = cage^5

* Gender
gen male = sex == 1

* Survey year 1990 or earlier 
capt drop sy1990
gen sy1990 = syear <= 1990

* Head or partner of head
gen hhstate = inlist(d11105, 1,2) if d11105 < .
lab var hhstate "hh-state: Head or partner of head" 

* Dummy for living together with parents 
gen withparents = d11105==3 if d11105 < .


* labor earnings 
clonevar earn = i11110
* earnings of partner
clonevar Pearn = Pi11110

* years of education
clonevar yed = d11109

* years of education (partner) 
clonevar Pyed = Pd11109

* working state and work hours
clonevar wos = e11103
lab var wkhrs "Work hours (week day)"

* work experience
lab var pgexpft "Work exp (full-time), months"
gen noexpft = pgexpft == 0 if pgexpft < .
lab var noexpft "No work exp"

* marital state and partnership
clonevar mar = d11104
recode mar (5=4) // recode separated to divorced
recode d11104 (1 = 0 "married") (3 4 5 = 1 "previously married") (2 = 2 "single"), gen(mstate)

* partner in hh (cohabitation)
gen cohab = !mi(parid)

* health 
clonevar health = m11125

* hh size
gen hhsize50 = hgsize/50

* Kids
recode h11101 (0=0 "no kids") (1 = 1 "1 kid") (2/max=2 "2+ kids"), gen(kids014)


* NEW
* TOPCODE housework hours
* weekday - housework 
replace hw = 15 if hw > 15 & hw < .
gen cchrs = hrscc
* child care
replace cchrs = 15 if cchrs > 15 & cchrs < .
lab var cchrs "childcare hours (top-coded 15)"

* weekend hours 
replace housew_sat = 15 if housew_sat > 15 & housew_sat < .
replace housew_sun = 15 if housew_sun > 15 & housew_sun < .
replace hrscc_sat = 15 if hrscc_sat > 15 & hrscc_sat < .
replace hrscc_sun = 15 if hrscc_sun > 15 & hrscc_sun < .

gen wkeffhrs = pgtatzeit/5
lab var wkeffhrs "effective working hours per week day"

keep pid syear withparents eintritt sex gebjahr psample wave hid wkhrs wkeffhrs cchrs gebj age hw /// summary
		 housew_sat housew_sun hrscc_sat hrscc_sun  ///
		 cgebj cgebj2 cgebj3 cage cage2 cage3 cage4 cage5 male sy1990 hhstate /// 
		 yed wos noexpft mar mstate cohab parid partner health hhsize50 kids014   /// sumkids ageychld agegrpych
		  pgexpft h11* Pyed earn Pearn i11102 Pwkhrs e11103 Pe11103 i11210 y11101 d11106 d11107 i11202

save "${tempDir}/01_pool_samples", replace
