/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Leopold, T., Skopek, J., and F. Schulz (2018). 
  Gender Convergence in Housework Time: A Life Course and Cohort Perspective
  Sociological Science. 		
    
  03_appendix_model-comparisons.do
  
  Compare various models. Based on this we decided for the final model. 
  Detailed analyses that are run here are not reported in the manuscript.  
 ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

do config

use "${tempDir}/01_pool_samples", clear

unique pid // 20736, 219547



* Women
* Selection of the Baseline Model (nested models) baseline model: unstructured covariance (better fit than unstructured)
* M1 - linear C, linear Age, interaction
mixed hw c.cgebj c.cage c.cage#c.cgebj i.sy1990 if male == 0 || pid: cage , cov(uns)
est store m1 

* M2 - quadratic C, linear age, interaction 
mixed hw c.cgebj c.cgebj2 c.cage c.cage#c.cgebj i.sy1990 if male == 0 || pid: cage , cov(uns)
est store m2 

* M3 - triple C (not better!) 
mixed hw c.cgebj c.cgebj2 c.cgebj3 c.cage c.cage#c.cgebj i.sy1990 if male == 0 || pid: cage , cov(uns)
est store m3 
// -> we stay with quadratic cohort fit

est stat m1 m2 m3
lrtest m2 m1
lrtest m3 m2
est table m1 m2 m3, star b(%9.3f)

* M4 - go on with quad cohort term
* add age in change equation
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage#c.cgebj i.sy1990 if male == 0 || pid: cage , cov(uns)
est store m4

* add random term for cage2
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage#c.cgebj i.sy1990 if male == 0 || pid: cage cage2, cov(uns)
est store m4b

est stat m2 m4 m4b
lrtest m4 m2 
lrtest m4b m4

est table m2 m4 m4b, star b(%9.3f)

* use 4b and 
* M5 - add age sqrt to change
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage#c.cgebj i.sy1990 if male == 0 || pid: cage cage2, cov(uns)
est store m5

est stat m2 m4 m4b m5
est table m2 m4 m4b m5, star b(%9.3f)


est stat m4 m4b m5  
// remove the second random slope
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage#c.cgebj i.sy1990 if male == 0 || pid: cage, cov(uns)
est store m5c

est stat m4 m4b m5 m5c  
est table m2 m4 m4b m5 m5c, star b(%9.3f)
lrtest m5 m4b
lrtest m5c m5
lrtest m5c m4


* M6 - add age to three to change
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj i.sy1990 if male == 0 || pid: cage cage2, cov(uns)
est store m6

* M6c - remove second random slope
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj i.sy1990 if male == 0 || pid: cage , cov(uns)
est store m6c

est stat m4 m4b m5 m5c m6 m6c 
est table m5 m5c m6 m6c, star b(%9.3f)
lrtest m6 m5
lrtest m6c m6
lrtest m6c m5c

* use m6
* M7a - add interaction cage2 x gebj
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj i.sy1990 if male == 0 || pid: cage cage2, cov(uns)
est store m7a

est stat  m6 m6c m7a
lrtest m7a m6

* M7b - add interaction cage3 x gebj
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj c.cage3#c.cgebj i.sy1990 if male == 0 || pid: cage cage2, cov(uns)
est store m7b

est stat  m6 m6c m7a m7b
lrtest m7b m7a


* M8a 
* simplify the covariance structure: independent
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj i.sy1990 if male == 0 || pid: cage cage2, cov(independent)
est store m8a

est stat m7a m8a 
lrtest m7a m8a

* M8b
* drop second random slope
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj i.sy1990 if male == 0 || pid: cage, cov(uns)
est store m8b

est stat m7a m8b 
lrtest m7a m8b

* M9a - add interaction cage x gebj2
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage#c.cgebj2 i.sy1990 if male == 0 || pid: cage cage2, cov(uns)
est store m9a

est stat m7a m9a 
lrtest m9a m6

// Model 7a seems to fit best 
// add control for sample 
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj i.sy1990 i.psample if male == 0 || pid: cage cage2, cov(uns)
est store m7a_psample
lrtest m7a_psample m7a // significant
est stat m7a_psample m7a // 

est table m7a_psample m7a, star b(%9.3f) // coefficients do not change much ==> omit sample variable

est restore m7a

// Compare 7a with 8b (with simpler covariance structure)
// 8b has worse fit but may have very similar coefficients (the graphs produced below look extremely similar)
est table m7a m8b, star b(%9.3f)
// compare fixed effects with coefplot
coefplot m7a m8b, name(compare_m7a_m8b, replace)
graph export women_compare_m7a_m8b.pdf, replace



// Decision for Model 8b! 

exit


// Some additional stuff


// Synthetic cohort projection
foreach mod in 4 4b 5 6 6c 7a 7b 8a 8b 9a {  
local model m`mod'
est restore `model'

capt drop y* 

rename sy1990 _sy1990
sum _sy1990
gen sy1990 = r(mean)
predict yf if male == 0 // e(sample)==1, xb

// Plot the Age-vector graph
twoway (line yf age if gebjahr==1920 & age <= 85, sort) ///
	   (line yf age if gebjahr==1925, sort) ///
	   (line yf age if gebjahr==1930, sort) ///
	   (line yf age if gebjahr==1935, sort) ///
	   (line yf age if gebjahr==1940, sort) ///
	   (line yf age if gebjahr==1945, sort) ///
	   (line yf age if gebjahr==1950, sort) ///
	   (line yf age if gebjahr==1955, sort) ///
	   (line yf age if gebjahr==1960, sort) ///
	   (line yf age if gebjahr==1965, sort) ///
	   (line yf age if gebjahr==1970, sort) ///
	   (line yf age if gebjahr==1975, sort) ///
	   (line yf age if gebjahr==1980, sort) ///
	   (line yf age if gebjahr==1985, sort) ///
	   (line yf age if gebjahr==1990, sort) ///
	   , legend(lab(15 "1990") lab(14 "1985") lab(13 "1980") lab(12 "1975") lab(11 "1970") lab(10 "1965") lab(9 "1960") lab(8 "1955") lab(7 "1950") ///
				lab(6 "1945") lab(5 "1940") lab(4 "1935") lab(3 "1930") lab(2 "1925") lab(1 "1920") row(3) size(small)) ///
				name(women_`model', replace)  ylabel(0(1)6) title("Women") xlabel(20(10)90)
graph export women_`model'.pdf, replace

drop sy1990
rename _sy1990 sy1990

}

// compare with a descriptive graph 
preserve
	// keep if inlist(gebjahr, 1920, 1930, 1940, 1950, 1960, 1970, 1980)
	
	// smooth
	gen geb2 = 1920 if inrange(gebjahr, 1917,1923)
	replace geb2 = 1930 if inrange(gebjahr, 1927,1933)
	replace geb2 = 1940 if inrange(gebjahr, 1937,1943)
	replace geb2 = 1950 if inrange(gebjahr, 1947,1953)
	replace geb2 = 1960 if inrange(gebjahr, 1957,1963)
	replace geb2 = 1960 if inrange(gebjahr, 1957,1963)
	replace geb2 = 1970 if inrange(gebjahr, 1967,1973)
	replace geb2 = 1980 if inrange(gebjahr, 1977,1983)
	
	collapse (mean) hw , by(male geb2 age)
	rename geb2 gebjahr
	li
	graph twoway lowess hw age if gebjahr==1920 & male==0, 	lpattern(solid)    lcolor(red  )   lwidth (medthick) sort ///
			||	lowess hw age if gebjahr==1930  & male==0, 	lpattern(solid)    lcolor( green )   lwidth (medthick) sort ///
			||  lowess hw age if gebjahr==1940  & male==0, 	lpattern(solid)    lcolor( blue)   lwidth (medthick) sort ///
			||  lowess hw age if gebjahr==1950  & male==0, 	lpattern(solid)    lcolor(magenta)   lwidth (medthick) sort ///
			||	lowess hw age if gebjahr==1960  & male==0, 	lpattern(solid)    lcolor( cranberry )   lwidth (medthick) sort ///
			||  lowess hw age if gebjahr==1970  & male==0, 	lpattern(solid)    lcolor( gs8)   lwidth (medthick) sort ///
			||  lowess hw age if gebjahr==1980  & male==0, 	lpattern(solid)    lcolor(dkorange)   lwidth (medthick) sort ///
			||  lowess hw age if gebjahr==1920  & male==1, 	lpattern(dash)    lcolor(red  )   lwidth (medthick) sort ///
			||	lowess hw age if gebjahr==1930 & male==1, 	lpattern(dash)    lcolor( green )   lwidth (medthick) sort ///
			||  lowess hw age if gebjahr==1940 & male==1, 	lpattern(dash)    lcolor( blue)   lwidth (medthick) sort ///
			||  lowess hw age if gebjahr==1950 & male==1, 	lpattern(dash)    lcolor(magenta)   lwidth (medthick) sort ///
			||	lowess hw age if gebjahr==1960 & male==1, 	lpattern(dash)    lcolor( cranberry )   lwidth (medthick) sort ///
			||  lowess hw age if gebjahr==1970 & male==1, 	lpattern(dash)    lcolor( gs8)   lwidth (medthick) sort ///
			||  lowess hw age if gebjahr==1980 & male==1, 	lpattern(dash)    lcolor(dkorange)   lwidth (medthick) sort ///
	title("Gender Differences in Routine Housework, West Germany 1985-2014" "Cohorts 1920 (10) 1980", size(small))	///
	graphregion(color(white) fcolor(white) icolor(white)) ylabel(0(0.2)4.8, labsize(vsmall) angle(0)) 	 			///	
	xlabel(20(5)80, labsize(vsmall)) xtitle("Age", size(vsmall)) ytitle("Hours of routine housework", size(vsmall))		///
	plotregion(color(white) fcolor(white) icolor(white)) legend(off) name(descriptive, replace)
	graph export descriptive.pdf, replace

restore 


// Estimate m8b for men

* M8b
* drop second random slope
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj i.sy1990 if male == 1 || pid: cage, cov(uns)
est store MENm8b


// Synthetic cohort projection
foreach mod in 8b  {  
local model MENm`mod'
est restore `model'

capt drop y* 

rename sy1990 _sy1990
sum _sy1990
gen sy1990 = r(mean)
predict yf if male == 1 // e(sample)==1, xb

// Plot the Age-vector graph
twoway (line yf age if gebjahr==1920 & age <= 85, sort) ///
	   (line yf age if gebjahr==1925, sort) ///
	   (line yf age if gebjahr==1930, sort) ///
	   (line yf age if gebjahr==1935, sort) ///
	   (line yf age if gebjahr==1940, sort) ///
	   (line yf age if gebjahr==1945, sort) ///
	   (line yf age if gebjahr==1950, sort) ///
	   (line yf age if gebjahr==1955, sort) ///
	   (line yf age if gebjahr==1960, sort) ///
	   (line yf age if gebjahr==1965, sort) ///
	   (line yf age if gebjahr==1970, sort) ///
	   (line yf age if gebjahr==1975, sort) ///
	   (line yf age if gebjahr==1980, sort) ///
	   (line yf age if gebjahr==1985, sort) ///
	   (line yf age if gebjahr==1990, sort) ///
	   , legend(lab(15 "1990") lab(14 "1985") lab(13 "1980") lab(12 "1975") lab(11 "1970") lab(10 "1965") lab(9 "1960") lab(8 "1955") lab(7 "1950") ///
				lab(6 "1945") lab(5 "1940") lab(4 "1935") lab(3 "1930") lab(2 "1925") lab(1 "1920") row(3) size(small)) ///
				name(men_`model', replace)  ylabel(0(1)6) title("Men (`mod')") xlabel(20(10)90)
graph export men_`model'.pdf, replace


drop sy1990
rename _sy1990 sy1990

}


// Now, we stay with model 8b 


/*******************************************************************************
WOMEN - Model 8B
*******************************************************************************/
// Baseline model 8b
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj i.sy1990 if male == 0 || pid: cage, cov(uns)
est store m8b

estout m8b, cell(b(f(%9.3f) star)) varwidth(15) stats(N N_g, f(%9.1g))



// attention: sumcohaby has massive missing values! Therefore, skipped from the equation. 
misstable sum cohab mstate summary agegrpych sumkids wkhrs hw yed hhstate hhsize50 health pgexpft
capt drop sample
mark sample if !mi(cohab, summary, agegrpych, sumkids, wkhrs, hw, yed, hhstate, hhsize50, health, pgexpft)

// baseline model with non-missing values
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj i.sy1990 if male == 0 & sample==1 || pid: cage, cov(uns)
est store m8b_0

// include only cohabitation and martial history 
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj  ///
		 i.cohab c.summary   /// cohabitaton, mar state and history 
		i.sy1990 /// 
		if male == 0 & sample == 1|| pid: cage, cov(uns)
est store m8b_1

// include only fertility
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj  ///
		 i.agegrpych c.sumkids /// fertility: number of children and age of youngest child
		 i.sy1990 /// 
		if male == 0 & sample == 1|| pid: cage, cov(uns)
est store m8b_2

// include only education and work
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj  ///
		 c.yed c.wkhrs i.noexpft c.pgexpft  /// education and work
		i.sy1990 /// 
		if male == 0 & sample == 1|| pid: cage, cov(uns)
est store m8b_3

// include all but without additional controls
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj  ///
		 i.cohab c.summary   /// cohabitaton, mar state and history 
		 i.agegrpych c.sumkids /// fertility: number of children and age of youngest child
		 c.yed c.wkhrs i.noexpft c.pgexpft  /// education and work
		i.sy1990 ///
		if male == 0 & sample == 1|| pid: cage, cov(uns)
est store m8b_4

// full model
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj  ///
		 i.cohab c.summary   /// cohabitaton, mar state and history 
		 i.agegrpych c.sumkids /// fertility: number of children and age of youngest child
		 c.yed c.wkhrs i.noexpft c.pgexpft c.health /// education and work
		i.sy1990 c.hhsize50 i.hhstate c.health /// control variables
		if male == 0 & sample == 1|| pid: cage, cov(uns)
est store m8b_5

/*
// check for non-linearities 
// categorize cumulative variables
recode summary (0 = 0 "never married") (1/5 = 1 "1-5 yrs") ///
			   (6/10 = 2 "6-10 yrs") (11/20 = 3 "11-20 yrs") ///
			   (21/max = 4 "21+ yrs"), gen(marexpgrp)
recode sumkids (0/1 = 0 "no/1 kid") (2 = 1 "2 kids") (3/max=2 "3+ kids"), gen(kids)

recode pgexpft (0/12 = 0 "0-12 months") (12.00001/24 = 1 "12-24 months") (24.00001/36 = 2 "24-36 months") ///
			   (36.00001/max = 2 "36+ months"), gen(pgexpftgrp)

mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj  ///
		 i.cohab i.marexpgrp   /// cohabitaton, mar state and history 
		 i.agegrpych i.kids /// fertility: number of children and age of youngest child
		 c.yed c.wkhrs i.noexpft i.pgexpftgrp c.health /// education and work
		i.sy1990 c.hhsize50 i.hhstate /// control variables
		if male == 0 & sample == 1|| pid: cage, cov(uns)
est store m8b_1b
*/
// Output (note: correlation not covariance for random terms is displayed!)
esttab m8b_0 m8b_1 m8b_2 m8b_3 m8b_4 m8b_5 , replace cell(b(f(%9.3f) star)) /// 
		varwidth(35) stats(N ll, f(%9.1g)) lab ///
		varlab(cgebj "Cohort" cgebj2 "Cohort^2" cage "Age" cage2 "Age^2" cage3 "Age^3" cage4 "Age^4" ///
			   c.cage#c.cgebj "Age x Cohort" c.cage2#c.cgebj "Age^2 x Cohort" hhsize50 "HH-size (m^2/50)" ///
			   health "Health (sat.)" pgexpft "LFX FT (years)" ///
			   , elist(hw:_cons "{break}{hline @width}")) ///
			   transform(lns*: exp(2*@) 2*exp(2*@) atr*: tanh(@) (1-tanh(@)^2)) ///
			   eqlabels("" "var(Age)" "var(Constant)" "corr(Age, Constant)" "var(Resid)", none) ///
			   mlabels(, titles) collabels(, none) mgroups(, none)
// write			   
esttab m8b_0 m8b_1 m8b_2 m8b_3 m8b_4 m8b_5  using "${logDir}/m8b_women.smcl", replace cell(b(f(%9.3f) star)) /// 
		varwidth(35) stats(N ll, f(%9.1g)) lab ///
		varlab(cgebj "Cohort" cgebj2 "Cohort^2" cage "Age" cage2 "Age^2" cage3 "Age^3" cage4 "Age^4" ///
			   c.cage#c.cgebj "Age x Cohort" c.cage2#c.cgebj "Age^2 x Cohort" hhsize50 "HH-size (m^2/50)" ///
			   health "Health (sat.)" ///
			   , elist(hw:_cons "{break}{hline @width}")) ///
			   transform(lns*: exp(2*@) 2*exp(2*@) atr*: tanh(@) (1-tanh(@)^2)) ///
			   eqlabels("" "var(Age)" "var(Constant)" "corr(Age, Constant)" "var(Resid)", none)  ///
			   mlabels(, titles) collabels(, none) mgroups(, none)

			   
// Create a plot that only shows the age-cohort trajectories with a standardized origin

foreach mod of numlist 0/5 {
	est restore m8b_`mod'
	mat c`mod' = e(b)
} 

// local twplot ""
foreach cohort of numlist 1920(10)1990 {
	// find out age ranges for each cohort (full sample)
	sum age if male == 0 & gebjahr == `cohort' & age < 75
	local min = `r(min)'
	local max = `r(max)' 
	// use coefficients
	foreach mod of numlist 0/5 { 
		local mat "c`mod'"
		#delimit ;
		local function`mod' "`mat'[1,3]*(x - 45)/10 + 
							 `mat'[1,4]*((x - 45)/10)^2 + 
							 `mat'[1,5]*((x - 45)/10)^3 + 
							 `mat'[1,6]*((x - 45)/10)^4 + 
							 `mat'[1,7]*((x - 45)/10)*(`cohort' - 1955)/10 + 
							 `mat'[1,8]*((x - 45)/10)^2*(`cohort' - 1955)/10 
							 - ( 
							 `mat'[1,3]*(`min' - 45)/10 + 
							 `mat'[1,4]*((`min' - 45)/10)^2 + 
							 `mat'[1,5]*((`min' - 45)/10)^3 + 
							 `mat'[1,6]*((`min' - 45)/10)^4 + 
							 `mat'[1,7]*((`min' - 45)/10)*(`cohort' - 1955)/10 + 
							 `mat'[1,8]*((`min' - 45)/10)^2*(`cohort' - 1955)/10 
							 )";
		#delimit cr
	}
	// local twplot "`twplot'(function y = `function`cohort'', range(`min' `max')) "
	twoway (function y = `function0', range(`min' `max') lcol(cranberry) lpat(solid) ) ///
		   (function y = `function1', range(`min' `max') lcol(green*1.5) lpat(shortdash)) ///
		   (function y = `function2', range(`min' `max') lcol(green*.5) lpat(dash)) ///
		   (function y = `function3', range(`min' `max') lcol(gs10) lpat(shortdash)) ///
		   (function y = `function4', range(`min' `max') lcol(gs4) lpat(dash)) ///
		   (function y = `function5', range(`min' `max') lcol(gs0) lpat(solid)) ///
		   , name(c`cohort', replace) legend(lab(1 "0") lab(2 "1") lab(3 "2") lab(4 "3") lab(5 "4") lab(6 "5") rows(2) size(small)) ///
			 xtitle(Age) ytitle("Prediction (from origin)") title("Cohort `cohort'") ///
			 ylabel(-2(.5)2) xmtick(`min'(1)`max')
}
grc1leg c1920 c1930 c1940 c1950, cols(2) name(panel1, replace) iscale(*.7) title("Women 1920-1950")
graph display panel1, ysize(15) xsize(15)

grc1leg c1960 c1970 c1980 c1990, cols(2) name(panel2, replace) iscale(*.7) title("Women 1960-1990")
graph display panel2, ysize(15) xsize(15)

			   
// Plot how the complex age effect is changing by adding all the covariates (at average cohort)
est restore m8b_0
mat c0 = e(b) 
est restore m8b_1 
mat c1 = e(b) 
bys pid (syear): gen first = _n==1
sum gebj if first == 1 & male == 0 // 1954
 
twoway (function y = c0[1,3]*(x - 45)/10 + /// age
					 c0[1,4]*((x - 45)/10)^2 + /// age^2
					 c0[1,5]*((x - 45)/10)^3 + /// age^3
					 c0[1,6]*((x - 45)/10)^4 + /// age^4
					 c0[1,7]*((x - 45)/10)*(1954 - 1955)/10 + /// age x gebj
					 c0[1,8]*((x - 45)/10)^2*(1954 - 1955)/10 /// age^2 x gebj
					 - ( /// set origin to 0
					 c0[1,3]*(20 - 45)/10 + /// age
					 c0[1,4]*((20 - 45)/10)^2 + /// age^2
					 c0[1,5]*((20 - 45)/10)^3 + /// age^3
					 c0[1,6]*((20 - 45)/10)^4 + /// age^4
					 c0[1,7]*((20 - 45)/10)*(1954 - 1955)/10 + /// age x gebj
					 c0[1,8]*((20 - 45)/10)^2*(1954 - 1955)/10 /// age^2 x gebj
					 ) ///
		, range(20 80))  ///
	   (function y = c1[1,3]*(x - 45)/10 + /// age
					 c1[1,4]*((x - 45)/10)^2 + /// age^2
					 c1[1,5]*((x - 45)/10)^3 + /// age^3
					 c1[1,6]*((x - 45)/10)^4 + /// age^4
					 c1[1,7]*((x - 45)/10)*(1954 - 1955)/10 + /// age x gebj
					 c1[1,8]*((x - 45)/10)^2*(1954 - 1955)/10 /// age^2 x gebj
					 - ( /// set origin to 0
					 c1[1,3]*(20 - 45)/10 + /// age
					 c1[1,4]*((20 - 45)/10)^2 + /// age^2
					 c1[1,5]*((20 - 45)/10)^3 + /// age^3
					 c1[1,6]*((20 - 45)/10)^4 + /// age^4
					 c1[1,7]*((20 - 45)/10)*(1954 - 1955)/10 + /// age x gebj
					 c1[1,8]*((20 - 45)/10)^2*(1954 - 1955)/10 /// age^2 x gebj
					 ) ///
		, range(20 80)) /// 
		, legend(lab(1 "0") lab(2 "1") size(small) title("Model", size(small))) ///
		  xtitle(Age) title("Women: Change over age (Cohort = 1954)") name(ageeff_women, replace)
graph export "${logDir}/ageeff_women.pdf", replace

// Plot how the cohort effect is changing by adding covariates (at average)			   
twoway (function y = c0[1,1]*(x - 1955)/10  + /// gebj
					 c0[1,2]*((x - 1955)/10 )^2 + /// gebj2^2
					 c0[1,7]*((45 - 45)/10)*(x - 1955)/10 + /// age x gebj
					 c0[1,8]*((45 - 45)/10)^2*(x - 1955)/10 /// age^2 x gebj
					 - ( ///
					 c0[1,1]*(1920 - 1955)/10  + /// gebj
					 c0[1,2]*((1920 - 1955)/10 )^2 + /// gebj2^2
					 c0[1,7]*((45 - 45)/10)*(1920 - 1955)/10 + /// age x gebj
					 c0[1,8]*((45 - 45)/10)^2*(1920 - 1955)/10 /// age^2 x gebj
					 ) ///
		, range(1920 1990)) ///
	   (function y = c1[1,1]*(x - 1955)/10  + /// gebj
					 c1[1,2]*((x - 1955)/10 )^2 + /// gebj2^2
					 c1[1,7]*((45 - 45)/10)*(x - 1955)/10 + /// age x gebj
					 c1[1,8]*((45 - 45)/10)^2*(x - 1955)/10 /// age^2 x gebj
					 - ( ///
					 c1[1,1]*(1920 - 1955)/10  + /// gebj
					 c1[1,2]*((1920 - 1955)/10 )^2 + /// gebj2^2
					 c1[1,7]*((45 - 45)/10)*(1920 - 1955)/10 + /// age x gebj
					 c1[1,8]*((45 - 45)/10)^2*(1920 - 1955)/10 /// age^2 x gebj
					 ) ///
		, range(1920 1990)) /// 
		, legend(lab(1 "0") lab(2 "1") size(small) title("Model", size(small)))	 ///
		  xtitle("Birth cohort") title("Women: Cohort change (Age = 45)") name(coheff_women, replace)
graph export "${logDir}/coheff_women.pdf", replace			   




/*******************************************************************************
MEN - Model 8B
*******************************************************************************/
// Baseline model 8b
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj i.sy1990 if male == 1 || pid: cage, cov(uns)
est store Mm8b

estout Mm8b, cell(b(f(%9.3f) star)) varwidth(15) stats(N N_g, f(%9.1g))

// baseline model with non-missing values
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj i.sy1990 if male == 1 & sample==1 || pid: cage, cov(uns)
est store Mm8b_0

// same estimates 
estout Mm8b Mm8b_0, cell(b(f(%9.3f) star)) varwidth(15) stats(N N_g, f(%9.1g))
coefplot Mm8b Mm8b_0

// Model controlling for various variables
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj  ///
		 i.cohab c.summary   /// cohabitaton, mar state and history 
		 i.agegrpych c.sumkids /// fertility: number of children and age of youngest child
		 c.yed c.wkhrs i.noexpft c.pgexpft c.health /// education and work
		i.sy1990 c.hhsize50 i.hhstate /// control variables
		if male == 1 & sample == 1|| pid: cage, cov(uns)
est store Mm8b_1

mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj  ///
		 i.cohab i.marexpgrp   /// cohabitaton, mar state and history 
		 i.agegrpych i.kids /// fertility: number of children and age of youngest child
		 c.yed c.wkhrs i.noexpft i.pgexpftgrp c.health /// education and work
		i.sy1990 c.hhsize50 i.hhstate /// control variables
		if male == 1 & sample == 1|| pid: cage, cov(uns)
est store Mm8b_1b

// Output (note: correlation not covariance for random terms is displayed!)
esttab Mm8b_0 Mm8b_1 Mm8b_1b , replace cell(b(f(%9.3f) star)) /// 
		varwidth(35) stats(N ll, f(%9.1g)) lab ///
		varlab(cgebj "Cohort" cgebj2 "Cohort^2" cage "Age" cage2 "Age^2" cage3 "Age^3" cage4 "Age^4" ///
			   c.cage#c.cgebj "Age x Cohort" c.cage2#c.cgebj "Age^2 x Cohort" hhsize50 "HH-size (m^2/50)" ///
			   health "Health (sat.)" pgexpft "LFX FT (moths)" ///
			   , elist(hw:_cons "{break}{hline @width}")) ///
			   transform(lns*: exp(2*@) 2*exp(2*@) atr*: tanh(@) (1-tanh(@)^2)) ///
			   eqlabels("" "var(Age)" "var(Constant)" "corr(Age, Constant)" "var(Resid)", none) 
// write			   
esttab Mm8b_0 Mm8b_1 Mm8b_1b using "${logDir}/m8b_men.smcl", replace cell(b(f(%9.3f) star)) /// 
		varwidth(35) stats(N ll, f(%9.1g)) lab ///
		varlab(cgebj "Cohort" cgebj2 "Cohort^2" cage "Age" cage2 "Age^2" cage3 "Age^3" cage4 "Age^4" ///
			   c.cage#c.cgebj "Age x Cohort" c.cage2#c.cgebj "Age^2 x Cohort" hhsize50 "HH-size (m^2/50)" ///
			   health "Health (sat.)" ///
			   , elist(hw:_cons "{break}{hline @width}")) ///
			   transform(lns*: exp(2*@) 2*exp(2*@) atr*: tanh(@) (1-tanh(@)^2)) ///
			   eqlabels("" "var(Age)" "var(Constant)" "corr(Age, Constant)" "var(Resid)", none) 
			   
// Plot how the complex age effect is changing by adding all the covariates (at average cohort)
est restore Mm8b_0
mat c0 = e(b) 
est restore Mm8b_1 
mat c1 = e(b) 
sum gebj if first == 1 & male == 1 // 1954
 
twoway (function y = c0[1,3]*(x - 45)/10 + /// age
					 c0[1,4]*((x - 45)/10)^2 + /// age^2
					 c0[1,5]*((x - 45)/10)^3 + /// age^3
					 c0[1,6]*((x - 45)/10)^4 + /// age^4
					 c0[1,7]*((x - 45)/10)*(1954 - 1955)/10 + /// age x gebj
					 c0[1,8]*((x - 45)/10)^2*(1954 - 1955)/10 /// age^2 x gebj
					 - ( /// set origin to 0
					 c0[1,3]*(20 - 45)/10 + /// age
					 c0[1,4]*((20 - 45)/10)^2 + /// age^2
					 c0[1,5]*((20 - 45)/10)^3 + /// age^3
					 c0[1,6]*((20 - 45)/10)^4 + /// age^4
					 c0[1,7]*((20 - 45)/10)*(1954 - 1955)/10 + /// age x gebj
					 c0[1,8]*((20 - 45)/10)^2*(1954 - 1955)/10 /// age^2 x gebj
					 ) ///
		, range(20 80))  ///
	   (function y = c1[1,3]*(x - 45)/10 + /// age
					 c1[1,4]*((x - 45)/10)^2 + /// age^2
					 c1[1,5]*((x - 45)/10)^3 + /// age^3
					 c1[1,6]*((x - 45)/10)^4 + /// age^4
					 c1[1,7]*((x - 45)/10)*(1954 - 1955)/10 + /// age x gebj
					 c1[1,8]*((x - 45)/10)^2*(1954 - 1955)/10 /// age^2 x gebj
					 - ( /// set origin to 0
					 c1[1,3]*(20 - 45)/10 + /// age
					 c1[1,4]*((20 - 45)/10)^2 + /// age^2
					 c1[1,5]*((20 - 45)/10)^3 + /// age^3
					 c1[1,6]*((20 - 45)/10)^4 + /// age^4
					 c1[1,7]*((20 - 45)/10)*(1954 - 1955)/10 + /// age x gebj
					 c1[1,8]*((20 - 45)/10)^2*(1954 - 1955)/10 /// age^2 x gebj
					 ) ///
		, range(20 80)) /// 
		, legend(lab(1 "0") lab(2 "1") size(small) title("Model", size(small))) ///
		  xtitle(Age) title("Men: Change over age (Cohort = 1954)") name(ageeff_men, replace)
graph export "${logDir}/ageeff_men.pdf", replace

// Plot how the cohort effect is changing by adding covariates (at average)			   
twoway (function y = c0[1,1]*(x - 1955)/10  + /// gebj
					 c0[1,2]*((x - 1955)/10 )^2 + /// gebj2^2
					 c0[1,7]*((45 - 45)/10)*(x - 1955)/10 + /// age x gebj
					 c0[1,8]*((45 - 45)/10)^2*(x - 1955)/10 /// age^2 x gebj
					 - ( ///
					 c0[1,1]*(1920 - 1955)/10  + /// gebj
					 c0[1,2]*((1920 - 1955)/10 )^2 + /// gebj2^2
					 c0[1,7]*((45 - 45)/10)*(1920 - 1955)/10 + /// age x gebj
					 c0[1,8]*((45 - 45)/10)^2*(1920 - 1955)/10 /// age^2 x gebj
					 ) ///
		, range(1920 1990)) ///
	   (function y = c1[1,1]*(x - 1955)/10  + /// gebj
					 c1[1,2]*((x - 1955)/10 )^2 + /// gebj2^2
					 c1[1,7]*((45 - 45)/10)*(x - 1955)/10 + /// age x gebj
					 c1[1,8]*((45 - 45)/10)^2*(x - 1955)/10 /// age^2 x gebj
					 - ( ///
					 c1[1,1]*(1920 - 1955)/10  + /// gebj
					 c1[1,2]*((1920 - 1955)/10 )^2 + /// gebj2^2
					 c1[1,7]*((45 - 45)/10)*(1920 - 1955)/10 + /// age x gebj
					 c1[1,8]*((45 - 45)/10)^2*(1920 - 1955)/10 /// age^2 x gebj
					 ) ///
		, range(1920 1990)) /// 
		, legend(lab(1 "0") lab(2 "1") size(small) title("Model", size(small)))	 ///
		  xtitle("Birth cohort") title("Men: Cohort change (Age = 45)") name(coheff_men, replace)
graph export "${logDir}/coheff_men.pdf", replace			   



