/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Leopold, T., Skopek, J., and F. Schulz (2018). 
  Gender Convergence in Housework Time: A Life Course and Cohort Perspective
  Sociological Science. 		
  
  PROJECT MASTER FILE
  
  The syntax of the empirical analysis is divided into sub-files, each 
  of which completes a specific step in the analysis. 
  
  This master file runs each of these steps in the right order. 
  You can run the complete analysis by executing this file.
 
  The syntax for the project is split into the following steps:
  
  DATA PREPARATION 
  
	00) Preparing survey data
  
	01) Selecting the analytical sample
  
  DATA ANALYSIS 
  
	02) All analyses presented in the paper
	   
	03) Appendix: Model comparisons
	   
 
  Detailed documentation can be found in the respective sub-files. 
  
  The configuration file 'config.do' defines important 
  settings (= paths) as well as various programs needed for the analysis. 
  Before executing any other do-file, this file should always run first. 
  
  Find details on how to obtain SOEP data in the README.txt. 

------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

// call the configuration file
run config 	

/*------------------------------------------------------------------------------
 ------------------------------------------------------------------------------
 
 DATA PREPARATION 
 
 ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

/*------------------------------------------------------------------------------
 0-0) Preparing the original survey data (SOEP v.29)
------------------------------------------------------------------------------*/
do 00_prepare.do

/*------------------------------------------------------------------------------
 0-1) Sample selection
------------------------------------------------------------------------------*/
do 01_pool_samples.do


/*------------------------------------------------------------------------------
 ------------------------------------------------------------------------------
 
 DATA ANALYSIS 
 
 ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

/*------------------------------------------------------------------------------
 All analyses presented in the paper. All Tables and Figures are generated. 
------------------------------------------------------------------------------*/
do 02_analyses.do

/*------------------------------------------------------------------------------
 Appendix: Model comparisons and elaboration of the final model
------------------------------------------------------------------------------*/
do 03_appendix_model-comparisons.do
